@@ -22,7 +22,7 @@ def bs(byte_array):
     return ''.join([chr(c) for c in byte_array])
 
 DEBUG = False
-__version__ = '0.4.1'
+__version__ = '0.4.2'
 apilevel = '2.0'
 threadsafety = 1
 paramstyle = 'qmark'
@@ -1140,12 +1140,12 @@ class BaseConnect:
     def commit(self):
         self._op_commit()
         (h, oid, buf) = self._op_response()
-        self.begin()
+        delattr(self, "trans_handle")
 
     def rollback(self):
         self._op_rollback()
         (h, oid, buf) = self._op_response()
-        self.begin()
+        delattr(self, "trans_handle")
 
     def close(self):
         if not hasattr(self, "db_handle"):
@@ -1186,6 +1186,7 @@ class BaseConnect:
         self.isolation_level = ISOLATION_LEVEL_READ_COMMITED
 
         self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        self.sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
         self.sock.connect((self.hostname, self.port))
 
     def set_isolation_level(self, isolation_level):
